<?php

/**
 * Initialize the options before anything else.
 */
add_action( 'admin_init', 'custom_theme_options', 1 );

/**
 * Build the custom settings & update OptionTree.
 */

function get_ot_items($op_name) {
  $array = array();
  $menu = ot_get_option($op_name);
  if ($menu != "") {
    foreach ($menu as $key => $item) {
      $array[] = array(
        'value' => $item["title"],
        'label' => $item["title"],
      );
    }
  }
  return $array;
}


function custom_theme_options() {
  /**
   * Get a copy of the saved settings array.
   */
  $saved_settings = get_option( 'option_tree_settings', array() );

  /**
   * Custom settings array that will eventually be
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array(
    'sections' => array(
        array(
          'id'       => 'home',
          'title'    => 'Home'
        ),
        array(
          'id'       => 'products',
          'title'    => 'Products'
        ),
      array(
        'id'       => 'contact',
        'title'    => 'Contact'
      )
    ),
    'settings' => array(

        // home

        array(
            'id'          => 'header_title',
            'label'       => 'Header Title',
            'type'        => 'text',
            'section'     => 'home'
        ),
        array(
            'id'          => 'header_description',
            'label'       => 'Header Description',
            'type'        => 'textarea-simple',
            'section'     => 'home'
        ),
        array(
            'id'          => 'header_learn_more',
            'label'       => 'Header Learn More Link',
            'type'        => 'text',
            'section'     => 'home'
        ),
        array(
            'id'          => 'section2_content',
            'label'       => 'Section2 Content',
            'type'        => 'textarea',
            'section'     => 'home'
        ),
        array(
            'id'          => 'section3_icons',
            'label'       => 'Section3 Icons',
            'type'        => 'list-item',
            'section'     => 'home',
            'operator'    => 'and',
            'settings'    => array(
                array(
                    'id'          => 'icon',
                    'label'       => 'Icon',
                    'type'        => 'upload',
                )
            )
        ),
        array(
            'id'          => 'section4_content',
            'label'       => 'Section4 Content',
            'type'        => 'textarea',
            'section'     => 'home'
        ),
        array(
            'id'          => 'section4_images',
            'label'       => 'Section4 Images',
            'type'        => 'list-item',
            'section'     => 'home',
            'operator'    => 'and',
            'settings'    => array(
                array(
                    'id'          => 'image',
                    'label'       => 'Image',
                    'type'        => 'upload',
                )
            )
        ),
        array(
            'id'          => 'section4_learn_more',
            'label'       => 'Section4 Learn More Link',
            'type'        => 'text',
            'section'     => 'home'
        ),
        array(
            'id'          => 'section5_content',
            'label'       => 'Section5 Content',
            'type'        => 'textarea',
            'section'     => 'home'
        ),
        array(
            'id'          => 'services_slider',
            'label'       => 'Services Slider',
            'type'        => 'list-item',
            'section'     => 'home',
            'operator'    => 'and',
            'settings'    => array(
                array(
                    'id'          => 'icon',
                    'label'       => 'Icon',
                    'type'        => 'upload',
                )
            )
        ),


        array(
            'id'          => 'products_items',
            'label'       => 'Products',
            'type'        => 'list-item',
            'section'     => 'products',
            'operator'    => 'and',
            'settings'    => array(
                array(
                    'id'          => 'image',
                    'label'       => 'Image',
                    'type'        => 'upload',
                )
            )
        ),
        array(
            'id'          => 'products_services_icons',
            'label'       => 'Services Icons',
            'type'        => 'list-item',
            'section'     => 'products',
            'operator'    => 'and',
            'settings'    => array(
                array(
                    'id'          => 'icon',
                    'label'       => 'Icon',
                    'type'        => 'upload',
                )
            )
        ),

        // contact

        array(
            'id'          => 'contact_email',
            'label'       => 'Contact Email',
            'type'        => 'text',
            'section'     => 'contact'
        )
    )
  );

  /* settings are not the same update the DB */
  if ($saved_settings !== $custom_settings) {
    update_option( 'option_tree_settings', $custom_settings );
  }

}

?>
